@@ -1,8 +1,8 @@
 from __future__ import annotations
 from typing import List
 from pydantic import BaseModel
-from models.OfferingModel import Offering
-from models.PropertyValueModel import PropertyValue
+from etsy_apiv3.models.OfferingModel import Offering
+from etsy_apiv3.models.PropertyValueModel import PropertyValue
 
 class Product(BaseModel):
     product_id: int
