@@ -6,6 +6,7 @@ from etsy_apiv3.models.TransactionModel import Transaction
 from etsy_apiv3.models.ShipmentModel import Shipment
 import pycountry
 
+
 @dataclass(frozen=True)
 class ReceiptType:
     UNSHIPPED = {"was_paid":True, "was_shipped":False}
@@ -64,3 +65,9 @@ class Receipt(BaseModel):
     @property
     def country_name(self):
         return pycountry.countries.get(alpha_2=self.country_iso).name
+
+    @property
+    def is_gift_wrap(self):
+        if self.gift_wrap_price.amount > 0:
+            return True
+        return False
\ No newline at end of file
