@@ -4,7 +4,7 @@ import requests
 from requests_oauthlib import OAuth2Session
 from etsy_apiv3.utils.RequestException import EtsyRequestException
 from etsy_apiv3.models.UserModel import OtherUser
-
+from etsy_apiv3.models import Shop
 
 def token_saver(token):
     return token
@@ -26,15 +26,19 @@ class EtsyAuth:
     
     
     
-    def __post_init__(self):
+    """def __post_init__(self):
         user_info_endpoint = "oauth/userinfo"
         response = self.request(user_info_endpoint, params={"client_id":self.session.client_id})
         object.__setattr__(self, "user_info", OtherUser(**response))
+    """
+    
+    """@property
+    def self_shop_id(self) -> int:
+        endpoint = f"users/{self.user_info.user_id}/shops"
+        response = self.request(endpoint)
+        return Shop(**response).shop_id
+    """
     
-    @property
-    def get_shop_id_self_user(self):
-        pass
-        
     def request(self, endpoint: str, method="GET", *args, **kwargs) -> dict:
         """ 
         Send Request to target endpoint by method
